

redis_host = 'localhost'
redis_port = 6379


apps = [
    'core',
]
